@@ -6,7 +6,6 @@ import subprocess
 from itertools import chain
 from collections import defaultdict, deque
 import argparse
-from operator import attrgetter
 import json
 from importlib import import_module
 import tempfile
@@ -21,18 +20,12 @@ try:
 except ImportError:
     from collections import Mapping
 
-try:
-    from pip._internal.utils.misc import get_installed_distributions
-    from pip._internal.operations.freeze import FrozenRequirement
-except ImportError:
-    from pip import get_installed_distributions, FrozenRequirement
-
 from pip._vendor import pkg_resources
 # inline:
 # from graphviz import backend, Digraph
 
 
-__version__ = '2.0.0'
+__version__ = '2.2.0'
 
 
 flatten = chain.from_iterable
@@ -50,9 +43,7 @@ def sorted_tree(tree):
     :rtype: collections.OrderedDict
 
     """
-    return OrderedDict(sorted([(k, sorted(v, key=attrgetter('key')))
-                               for k, v in tree.items()],
-                              key=lambda kv: kv[0].key))
+    return OrderedDict([(k, sorted(v)) for k, v in sorted(tree.items())])
 
 
 def guess_version(pkg_key, default='?'):
@@ -77,6 +68,23 @@ def guess_version(pkg_key, default='?'):
 
 
 def frozen_req_from_dist(dist):
+    # The `pip._internal.metadata` modules were introduced in 21.1.1
+    # and the `pip._internal.operations.freeze.FrozenRequirement`
+    # class now expects dist to be a subclass of
+    # `pip._internal.metadata.BaseDistribution`, however the
+    # `pip._internal.utils.misc.get_installed_distributions` continues
+    # to return objects of type
+    # pip._vendor.pkg_resources.DistInfoDistribution.
+    #
+    # This is a hacky backward compatible (with older versions of pip)
+    # fix.
+    try:
+        from pip._internal import metadata
+    except ImportError:
+        pass
+    else:
+        dist = metadata.pkg_resources.Distribution(dist)
+
     try:
         return FrozenRequirement.from_dist(dist)
     except TypeError:
@@ -110,8 +118,7 @@ class Package(object):
 
     @staticmethod
     def frozen_repr(obj):
-        fr = frozen_req_from_dist(obj)
-        return str(fr).strip()
+        return str(obj.as_requirement())
 
     def __getattr__(self, key):
         return getattr(self._obj, key)
@@ -119,6 +126,9 @@ class Package(object):
     def __repr__(self):
         return '<{0}("{1}")>'.format(self.__class__.__name__, self.key)
 
+    def __lt__(self, rhs):
+        return self.key < rhs.key
+
 
 class DistPackage(Package):
     """Wrapper class for pkg_resources.Distribution instances
@@ -524,6 +534,7 @@ def render_json(tree, indent):
     :rtype: str
 
     """
+    tree = tree.sort()
     return json.dumps([{'package': k.as_dict(),
                         'dependencies': [v.as_dict() for v in vs]}
                        for k, vs in tree.items()],
@@ -668,7 +679,7 @@ def render_conflicts_text(conflicts):
         print('Warning!!! Possibly conflicting dependencies found:',
               file=sys.stderr)
         # Enforce alphabetical order when listing conflicts
-        pkgs = sorted(conflicts.keys(), key=attrgetter('key'))
+        pkgs = sorted(conflicts.keys())
         for p in pkgs:
             pkg = p.render_as_root(False)
             print('* {}'.format(pkg), file=sys.stderr)
@@ -822,8 +833,7 @@ def main():
     result = handle_non_host_target(args)
     if result is not None:
         return result
-    pkgs = get_installed_distributions(local_only=args.local_only,
-                                       user_only=args.user_only)
+    pkgs = list(pkg_resources.working_set)
 
     tree = PackageDAG.from_pkgs(pkgs)
 
